==> nextcloud-app-bookmarks-1:4.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/eo.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Legosignaro",
    "No file provided for import" : "Neniu dosiero provizita por enporto",
    "Unsupported file type for import" : "Nesubtenita dosiertipo por enporto",
    "Recent Bookmarks" : "Lastaj legosignoj",
    "A Bookmark manager for Nextcloud" : "Mastrumilo de legosignoj por Nextcloud",
    "Select bookmark" : "Elekti legosignon",
    "Details" : "Detaloj",
    "Rename" : "Alinomi",
    "Move" : "Movi",
    "Delete" : "Forigi",
    "Search" : "Serĉi",
    "Select one or more tags" : "Elekti unu aŭ pliajn etikedojn",
    "New" : "Nova",
    "New folder" : "Nova dosierujo",
    "Grid view" : "Krada vido",
    "List view" : "Lista vido",
    "Move selection" : "Movi elekton",
    "Delete selection" : "Forigi elekton",
    "Select all" : "Elekti ĉion",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n legosignon elektitan","%n legosignojn elektitajn"],
    "Enter a link" : "Entajpu ligilon",
    "Enter folder title" : "Entajpu titolon de la dosierujo",
    "Root folder" : "Radika dosierujo",
    "Submit" : "Sendi",
    "Cancel" : "Nuligi",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Movo de %n dosierujo kaj kelkaj legosignoj","Movo de %n dosierujoj kaj kelkaj legosignoj"],
    "_Moving %n folder_::_Moving %n folders_" : ["Movo de %n dosierujo","Movo de %n dosierujoj"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Movo de %n legosigno","Movo de %n legosignoj"],
    "All bookmarks" : "Ĉiuj legosignoj",
    "Recent" : "Lastaj ŝanĝoj",
    "Untagged" : "Sen etikedo",
    "No bookmarks here" : "Neniu legosigno ĉi tie",
    "Add a bookmark" : "Aldoni legosignon",
    "Import" : "Importi",
    "Export" : "Eksporti",
    "Sorting" : "Ordigo",
    "Recently added" : "Lastaj aldonoj",
    "Alphabetically" : "Alfabete",
    "Most visited" : "Plej vizititaj",
    "Last modified" : "laŭ lasta modifo",
    "Client apps" : "Klientaj aplikaĵoj",
    "Also check out the collection of client apps that integrate with this app: " : "Ankaŭ vidu la programojn, kiuj uzas tiun aplikaĵon:",
    "Bookmarklet" : "Legosignilo",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Ŝovu tion al via retumila legosignaro  kaj alklaku ĝin por rapide aldoni al viaj legosignoj retpaĝon",
    "Add to {instanceName}" : "Aldoni al {instanceName}",
    "Clear data" : "Forviŝi datumojn",
    "Delete all bookmarks" : "Forigi ĉiujn legosignojn",
    "Do you really want to delete all your bookmarks?" : "Ĉu vi ja volas forigi ĉiujn viaj legosignoj?",
    "Title" : "Titolo",
    "Link" : "Ligilo",
    "Creation date" : "Krea dato",
    "Tags" : "Etikedoj",
    "Attachments" : "Dosieraj aldonaĵoj",
    "Notes" : "Notoj",
    "{time} ago" : "antaŭ {time}",
    "Owner" : "Posedanto",
    "Sharing" : "Kunhavigo",
    "Select a user or group" : "Elektu uzanton aŭ grupon",
    "Share link" : "Kunhavigi ligilon",
    "Copy link" : "Kopii ligilon",
    "Allow editing" : "Permesi modifon",
    "Link copied" : "Ligilo kopiita",
    "Select" : "Elekti",
    "Previews" : "Antaŭrigardoj",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Vi povas aŭ krei senpagan konton ĉe screeenly.com aŭ instali vian propran servilon.",
    "Screeenly API URL" : "API-adreso de Screeenly",
    "Screeenly API key" : "API-ŝlosilo de Screeenly",
    "Privacy" : "Privateco",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "„Legosignaro“ provos aliri retpaĝojn, kiujn vi aldonas por aldoni aŭtomate informojn pri ili.",
    "Enable accessing and collecting information from the web pages you add" : "Ebligi aliron al kaj kolekton de informoj el la retpaĝoj, kiujn vi aldonas",
    "Performance" : "Rendimento",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maksimuma nombro de legosignoj en unu konto. (0 por ne limigi; defaŭlte ne estas limigo)",
    "Failed to load settings" : "Ŝargo de agordoj malsukcesis",
    "Failed to save settings" : "Konservo de agordoj malsukcesis",
    "This URL is already bookmarked! Overwrite?" : "Tiu adreso jam ekzistas en viaj legosignoj! Anstataŭigi ĝin?",
    "Enter bookmark title" : "Entajpu titolon de la legosigno",
    "Folder" : "Dosierujo",
    "Save" : "Konservi",
    "Failed to find existing bookmark" : "Trovo de jam ekzistanta legosigno malsukcesis",
    "Failed to create bookmark" : "Kreo de legosigno malsukcesis",
    "Failed to save bookmark" : "Konservo de legosigno malsukcesis",
    "Failed to move bookmark" : "Movo de legosigno malsukcesis",
    "Failed to delete bookmark" : "Forigo de legosigno malsukcesis",
    "Failed to load tags" : "Ŝargo de la etikedoj malsukcesis",
    "Failed to load folders" : "Ŝargo de la dosierujoj malsukcesis",
    "Failed to delete folder" : "Forigo de la dosierujo malsukcesis",
    "Failed to create folder" : "Kreo de dosierujo malsukcesis",
    "Failed to fetch bookmarks." : "Ricevo de legosignoj malsukcesis.",
    "Failed to change setting" : "Ŝanĝo de agordo malsukcesis",
    "Bookmarks feed" : "Fluo de legosignoj"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-bookmarks-1:15.1.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/eo.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Legosignaro",
    "No file provided for import" : "Neniu dosiero provizita por enporto",
    "Link copied to clipboard" : "Ligilo kopiita al tondujo",
    "Select bookmark" : "Elekti legosignon",
    "Details" : "Detaloj",
    "Rename" : "Alinomi",
    "Copy link" : "Kopii ligilon",
    "Move" : "Movi",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n legosignon elektitan","%n legosignojn elektitajn"],
    "Move selection" : "Movi elekton",
    "Delete selection" : "Forigi elekton",
    "Select all" : "Elekti ĉion",
    "Go back" : "Reveni",
    "Select one or more tags" : "Elekti unu aŭ pliajn etikedojn",
    "New" : "Nova",
    "New folder" : "Nova dosierujo",
    "Search" : "Serĉi",
    "Empty trash bin" : "Malpleni rubujon",
    "Enter a link" : "Entajpu ligilon",
    "_%n folder_::_%n folders_" : ["%n dosierujo","%n dosierujoj"],
    "Add a bookmark" : "Aldoni legosignon",
    "Enter folder title" : "Entajpu titolon de la dosierujo",
    "Rename folder" : "Alinomigi dosierujon",
    "Submit" : "Sendi",
    "Cancel" : "Nuligi",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Movo de %n dosierujo kaj kelkaj legosignoj","Movo de %n dosierujoj kaj kelkaj legosignoj"],
    "_Moving %n folder_::_Moving %n folders_" : ["Movo de %n dosierujo","Movo de %n dosierujoj"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Movo de %n legosigno","Movo de %n legosignoj"],
    "All bookmarks" : "Ĉiuj legosignoj",
    "Recent" : "Lastaj ŝanĝoj",
    "Shared with you" : "Kunhavata kun vi",
    "Files" : "Dosieroj",
    "Delete" : "Forigi",
    "Untagged" : "Sen etikedo",
    "No bookmarks here" : "Neniu legosigno ĉi tie",
    "Client apps" : "Klientaj aplikaĵoj",
    "Also check out the collection of client apps that integrate with this app: " : "Ankaŭ vidu la programojn, kiuj uzas tiun aplikaĵon:",
    "Bookmarklet" : "Legosignilo",
    "Add to {instanceName}" : "Aldoni al {instanceName}",
    "Need help?" : "Ĉu necesas helpo?",
    "Title" : "Titolo",
    "Link" : "Ligilo",
    "Root folder" : "Radika dosierujo",
    "Tags" : "Etikedoj",
    "Notes" : "Notoj",
    "Link copied" : "Ligilo kopiita",
    "Owner" : "Posedanto",
    "Sharing" : "Kunhavigo",
    "Select a user or group" : "Elektu uzanton aŭ grupon",
    "Share link" : "Kunhavigi ligilon",
    "Allow editing" : "Permesi modifon",
    "Allow resharing" : "Permesi rekunhavigon",
    "Failed to save settings" : "Konservo de agordoj malsukcesis",
    "Failed to load settings" : "Ŝargo de agordoj malsukcesis",
    "Privacy" : "Privateco",
    "Enable accessing and collecting information from the web pages you add" : "Ebligi aliron al kaj kolekton de informoj el la retpaĝoj, kiujn vi aldonas",
    "Performance" : "Rendimento",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maksimuma nombro de legosignoj en unu konto. (0 por ne limigi; defaŭlte ne estas limigo)",
    "Previews" : "Antaŭrigardoj",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Vi povas aŭ krei senpagan konton ĉe screeenly.com aŭ instali vian propran servilon.",
    "Screeenly API URL" : "API-adreso de Screeenly",
    "Screeenly API key" : "API-ŝlosilo de Screeenly",
    "This URL is already bookmarked! Overwrite?" : "Tiu adreso jam ekzistas en viaj legosignoj! Anstataŭigi ĝin?",
    "Enter bookmark title" : "Entajpu titolon de la legosigno",
    "Folder" : "Dosierujo",
    "Save" : "Konservi",
    "What's new?" : "Kio nova?",
    "Failed to find existing bookmark" : "Trovo de jam ekzistanta legosigno malsukcesis",
    "Failed to create bookmark" : "Kreo de legosigno malsukcesis",
    "Failed to save bookmark" : "Konservo de legosigno malsukcesis",
    "Failed to move bookmark" : "Movo de legosigno malsukcesis",
    "Failed to delete bookmark" : "Forigo de legosigno malsukcesis",
    "Failed to load tags" : "Ŝargo de la etikedoj malsukcesis",
    "Failed to load folders" : "Ŝargo de la dosierujoj malsukcesis",
    "Failed to delete folder" : "Forigo de la dosierujo malsukcesis",
    "Failed to create folder" : "Kreo de dosierujo malsukcesis",
    "Failed to fetch bookmarks." : "Ricevo de legosignoj malsukcesis.",
    "Bookmarks feed" : "Fluo de legosignoj"
},
"nplurals=2; plural=(n != 1);");
